"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const cardNumber_1 = require("../cardNumber");
/**
 * A test suite for the Card component.
 */
(0, globals_1.describe)('Card', () => {
    /**
     * Tests the CheckCardNumber function to ensure that it correctly identifies valid card numbers.
     * @returns None
     */
    (0, globals_1.test)('Card is Valid', () => {
        /**
         * Checks if a given credit card number is valid using the Luhn algorithm.
         * @param {string} cardNumber - The credit card number to check.
         * @returns {boolean} - True if the card number is valid, false otherwise.
         * @example
         * expect(CheckCardNumber('6037 9918 3333 4444')).toBeTruthy();
         */
        (0, globals_1.expect)((0, cardNumber_1.CheckCardNumber)('6037 9918 3333 4444')).toBeTruthy();
        /**
         * Checks if a given credit card number is valid using the Luhn algorithm.
         * @param {string} cardNumber - The credit card number to check.
         * @returns {boolean} - True if the card number is valid, false otherwise.
         */
        (0, globals_1.expect)((0, cardNumber_1.CheckCardNumber)('5859831133334444')).toBeTruthy();
        /**
         * Checks if a given credit card number is valid using the Luhn algorithm.
         * @param {string} cardNumber - The credit card number to check.
         * @returns {boolean} - True if the card number is valid, false otherwise.
         * @example
         * expect(CheckCardNumber('5022-2910-3333-4444')).toBeTruthy();
         */
        (0, globals_1.expect)((0, cardNumber_1.CheckCardNumber)('5022-2910-3333-4444')).toBeTruthy();
    });
    /**
     * Test the CardBank function to ensure it correctly identifies the bank name of a given card number.
     * @param None
     * @returns None
     * @throws {Error} If the function does not return the expected bank name.
     */
    (0, globals_1.test)('Bank Card name', () => {
        /**
         * Tests the CardBank function to ensure that it correctly identifies the bank associated with a given credit card number.
         * @param {string} cardNumber - The credit card number to test.
         * @returns None
         * @throws {Error} If the CardBank function does not return the expected result.
         */
        (0, globals_1.expect)((0, cardNumber_1.CardBank)('5022293345678976')).toStrictEqual('پاسارگاد');
    });
});
